"""Utilities for asyncio-friendly file handling."""
from .threadpool import open

__version__ = "0.6.0"

__all__ = ["open"]
